@@ -8,7 +8,7 @@
 #
 package IO::Socket::Timeout;
 {
-  $IO::Socket::Timeout::VERSION = '0.25';
+  $IO::Socket::Timeout::VERSION = '0.26';
 }
 
 use strict;
@@ -111,7 +111,7 @@ BEGIN {
 
 package IO::Socket::Timeout::Role::SetSockOpt;
 {
-  $IO::Socket::Timeout::Role::SetSockOpt::VERSION = '0.25';
+  $IO::Socket::Timeout::Role::SetSockOpt::VERSION = '0.26';
 }
 use Carp;
 use Socket;
@@ -171,7 +171,7 @@ sub _set_sock_opt {
 
 package IO::Socket::Timeout::Role::PerlIO;
 {
-  $IO::Socket::Timeout::Role::PerlIO::VERSION = '0.25';
+  $IO::Socket::Timeout::Role::PerlIO::VERSION = '0.26';
 }
 use PerlIO::via::Timeout;
 
@@ -195,7 +195,7 @@ IO::Socket::Timeout - IO::Socket with read/write timeout
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -211,7 +211,7 @@ version 0.25
 
   # When using the socket:
   use Errno qw(ETIMEDOUT EWOULDBLOCK);
-  print $socket $request;
+  print $socket "some request";
   my $response = <$socket>;
   if (! $response && ( 0+$! == ETIMEDOUT || 0+$! == EWOULDBLOCK )) {
     die "timeout reading on the socket";
